const path = require('path');
const open = require('open');
const express = require('express');
const webpack = require('webpack');
const webpackDevMiddleware = require('webpack-dev-middleware');
const webpackHotMiddleware = require("webpack-hot-middleware");
const webpackDevConfig = require('./webpack.config.dev');
const app = express();

const PROTOCOL = process.env.PROTOCOL || 'http';
const HOST = process.env.HOST || 'localhost';
const PORT = process.env.PORT || 5000;
const compiler = webpack(webpackDevConfig);

const webpackDevMiddlewareInstance = webpackDevMiddleware(compiler, {
  // display no info to console (only warnings and errors)
	noInfo: false,
  // display nothing to the console
	quiet: false,
  // switch into lazy mode
	// that means no watching, but recompilation on every request
	// lazy: true,
  // public path to bind the middleware to
	// use the same as in webpack
	publicPath: '/',
  // options for formating the statistics
	stats: webpackDevConfig.stats,
  // turn off the server-side rendering mode
	serverSideRender: false,
});
app.use(webpackDevMiddlewareInstance);
webpackDevMiddlewareInstance.waitUntilValid(() => {
  // open browser when first build
  if (!webpackDevMiddlewareInstance.init) {
    open(`${PROTOCOL}://${HOST}:${PORT}`);
    webpackDevMiddlewareInstance.init = true;
  }
});
app.use(webpackHotMiddleware(compiler));
// static file
app.use(express.static(path.join(__dirname, '')));

app.listen(PORT, err => {
  if (err) {
    console.log(err);
    return;
  }
  console.log(`Listening at ${PROTOCOL}://${HOST}:${PORT}`);
});
