const path = require('path');
const webpack = require('webpack');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const defaultConfig = require('./default.config');
const svgConfig = require('./svg.config');

const commonConfig = {
  entry: {
    // 'perf': 'perf.js',
  },

  output: {
    path: defaultConfig.distPath,
    publicPath: '/',
    filename: '[name].bundle.js',
    chunkFilename: '[id].js',
  },

  resolve: {
    extensions: ['.js', '.jsx', '.vue'],
  },

  module: {
    rules: [
      // preLoaders
      {
        enforce: 'pre',
        test: /\.jsx?$/,
        exclude: /node_modules/,
        loader: 'eslint-loader',
        options: {
          baseConfig: {
            extends: ['scm/react'],
          },
          useEslintrc: false,
          emitError: true,
        },
      }, {
        enforce: 'pre',
        test: /\.vue$/,
        exclude: /node_modules/,
        loader: 'eslint-loader',
        options: {
          baseConfig: {
            extends: ['scm/vue'],
          },
          useEslintrc: false,
          emitError: true,
        },
      }, {
        enforce: 'pre',
        test: /\.svg$/,
        loader: 'svgo-loader?' + JSON.stringify(svgConfig),
      },
      // loaders
      {
        test: /\.jsx?$/,
        exclude: /node_modules/,
        loader: 'babel-loader',
        options: {
          babelrc: false,
          presets: [require.resolve('babel-preset-scm/react')],
          cacheDirectory: true,
        },
      }, {
        test: /\.json$/,
        loader: 'json-loader',
      }, {
        test: /\.html$/,
        loader: 'vue-html-loader?minimize=false',
      }, {
        test: /\.svg$/,
        loader: 'svg-sprite-loader',
      }, {
        test: /\.(svg|gif|png|jpe?g)(\?\S*)?$/,
        loader: 'url-loader',
        query: {
          limit: 1000,
          name: path.posix.join(defaultConfig.assetsPath, '[name].[hash:7].[ext]'),
        },
      },
    ],
  },

  plugins: [
    new webpack.NoEmitOnErrorsPlugin(),
    new HtmlWebpackPlugin({
      title: defaultConfig.title,
      filename: 'index.html',
      template: defaultConfig.template,
      cache: true,
    }),
  ],

  stats: {
    colors: true,
    reasons: true,
    hash: false,
    version: false,
    timings: true,
    chunks: false,
    chunkModules: false,
    cached: false,
    cachedAssets: false,
  },
}

module.exports = commonConfig;
