const webpack = require('webpack');
const merge = require('webpack-merge');
const NotifierPlugin = require('webpack-notifier');
const autoprefixer = require('autoprefixer');
const defaultConfig = require('./default.config');
const commonConfig = require('./webpack.config.common');

const AUTOPREFIXER = {
  browsers: [
    'Android >= 4',
    'Chrome >= 35',
    'Firefox >= 31',
    'Explorer >= 9',
    'iOS >= 7',
    'Opera >= 12',
    'Safari >= 7.1',
  ],
};

const devConfig = merge(commonConfig, {
  devtool: 'cheap-module-source-map',

  entry: [
    'webpack-hot-middleware/client?reload=true',
    defaultConfig.entry,
  ],

  module: {
    rules: [{
      test: /\.(sass|scss)$/,
      use: [{
        loader: 'style-loader'
      }, {
        loader: 'css-loader',
        options: {
          minimize: true,
        },
      }, {
        loader: 'postcss-loader',
        options: {
          plugins: [autoprefixer(AUTOPREFIXER)],
        },
      }, {
        loader: 'sass-loader',
      }],
    }, {
      test: /\.vue$/,
      loader: 'vue-loader',
      options: {
        extractCSS: false,
        autoprefixer: false,
        minimize: true,
        cssModules: {
          localIdentName: '[name]-[local]_[hash:base64:5]',
          camelCase: true,
        },
        loaders: {
          js: 'babel-loader',
        },
        postcss: {
          plugins: [autoprefixer(AUTOPREFIXER)],
        },
        preserveWhitespace: false,
      },
    }],
  },

  plugins: [
    new webpack.DefinePlugin({
      'process.env': {
        NODE_ENV: '"development"'
      },
    }),
    new NotifierPlugin({
      title: 'Scm',
      alwaysNotify: false,
    }),
    new webpack.optimize.CommonsChunkPlugin({
      names: 'vendor',
      filename: '[name].js',
      minChunks: 10,
    }),
    new webpack.HotModuleReplacementPlugin(),
  ],
});

module.exports = devConfig;


