const path = require('path');
const webpack = require('webpack');
const merge = require('webpack-merge');
const ExtractTextPlugin = require('extract-text-webpack-plugin');
const CleanWebpackPlugin = require('clean-webpack-plugin');
const autoprefixer = require('autoprefixer');
const defaultConfig = require('./default.config');
const commonConfig = require('./webpack.config.common.js');

const AUTOPREFIXER = {
  browsers: [
    'Android >= 4',
    'Chrome >= 35',
    'Firefox >= 31',
    'Explorer >= 9',
    'iOS >= 7',
    'Opera >= 12',
    'Safari >= 7.1',
  ],
};

const prodConfig = merge(commonConfig, {
  devtool: 'source-map',

  entry: defaultConfig.entry,

  output: {
    filename: '[name].[chunkhash:7].js',
    publicPath: defaultConfig.publicPath || '/',
    chunkFilename: 'async_chunk/[id].[chunkhash:7].js'
  },

  module: {
    rules: [{
      test: /\.(sass|scss)$/,
      use: ExtractTextPlugin.extract({
        fallback: 'style-loader',
        use: [{
          loader: 'css-loader',
          options: {
            minimize: true,
          },
        }, {
          loader: 'postcss-loader',
          options: {
            plugins: [autoprefixer(AUTOPREFIXER)],
          },
        }, {
          loader: 'sass-loader',
        }],
      }),
    }, {
      test: /\.vue$/,
      loader: 'vue-loader',
      options: {
        extractCSS: true,
        autoprefixer: false,
        minimize: true,
        cssModules: {
          localIdentName: '[name]-[hash:base64:5]',
          camelCase: true,
        },
        loaders: {
          js: 'babel-loader',
        },
        postcss: {
          plugins: [autoprefixer(AUTOPREFIXER)],
        },
        preserveWhitespace: false,
      },
    }],
  },

  plugins: [
    new CleanWebpackPlugin([path.basename(defaultConfig.distPath)], {
      root: path.dirname(defaultConfig.distPath),
    }),
    new webpack.DefinePlugin({
      'process.env': {
        NODE_ENV: '"production"',
      },
    }),
    new webpack.optimize.UglifyJsPlugin({
      compress: {
        warnings: false,
      },
      output: {
        comments: false,
      }
    }),
    new ExtractTextPlugin('[name].[contenthash:7].css'),
    new webpack.optimize.CommonsChunkPlugin({
      names: 'vendor',
      chunkFilename: '[name].[chunkhash:7].js',
      minChunks: 10,
    }),
  ],
});

module.exports = prodConfig;
